@@ -55,16 +55,29 @@ impl LinesHighlighter for PlusMinusHeaderHighlighter {
 impl PlusMinusHeaderHighlighter {
     fn highlighted(&self) -> String {
         if self.old_name == "/dev/null" {
+            // New file added
             let mut highlighted = String::new();
 
+            highlighted.push_str(BOLD);
+            highlighted.push_str("--- ");
+            highlighted.push_str(NORMAL_INTENSITY);
             highlighted.push_str(FAINT);
-            highlighted.push_str("--- /dev/null");
+            highlighted.push_str("/dev/null");
             highlighted.push_str(NORMAL);
             highlighted.push('\n');
 
             highlighted.push_str(BOLD);
-            highlighted.push_str("+++ ");
-            highlighted.push_str(&self.new_name);
+            highlighted.push_str("+++ NEW ");
+            if let Some(no_prefix) = self.new_name.strip_prefix("b/") {
+                highlighted.push_str(NORMAL_INTENSITY);
+                highlighted.push_str(FAINT);
+                highlighted.push_str("b/");
+                highlighted.push_str(NORMAL_INTENSITY);
+                highlighted.push_str(BOLD);
+                highlighted.push_str(no_prefix);
+            } else {
+                highlighted.push_str(&self.new_name);
+            }
             highlighted.push_str(NORMAL);
             highlighted.push('\n');
 
@@ -72,16 +85,29 @@ impl PlusMinusHeaderHighlighter {
         }
 
         if self.new_name == "/dev/null" {
+            // File deleted
             let mut highlighted = String::new();
 
             highlighted.push_str(BOLD);
-            highlighted.push_str("--- ");
-            highlighted.push_str(&self.old_name);
+            highlighted.push_str("--- DELETED ");
+            if let Some(no_prefix) = self.old_name.strip_prefix("a/") {
+                highlighted.push_str(NORMAL_INTENSITY);
+                highlighted.push_str(FAINT);
+                highlighted.push_str("a/");
+                highlighted.push_str(NORMAL_INTENSITY);
+                highlighted.push_str(BOLD);
+                highlighted.push_str(no_prefix);
+            } else {
+                highlighted.push_str(&self.old_name);
+            }
             highlighted.push_str(NORMAL);
             highlighted.push('\n');
 
+            highlighted.push_str(BOLD);
+            highlighted.push_str("+++ ");
+            highlighted.push_str(NORMAL_INTENSITY);
             highlighted.push_str(FAINT);
-            highlighted.push_str("+++ /dev/null");
+            highlighted.push_str("/dev/null");
             highlighted.push_str(NORMAL);
             highlighted.push('\n');
 
